@@ -5,7 +5,6 @@
 #include <QQmlExtensionPlugin>
 #include <QQmlEngine>
 #include "nameutils.h"
-#include "messagedialoghelper.h"
 
 class ComponentsPlugin : public QQmlExtensionPlugin
 {
@@ -31,10 +30,6 @@ void ComponentsPlugin::registerTypes(const char *uri)
     qmlRegisterSingletonType<NameUtils>(uri, 1, 0, "NameUtils", [](QQmlEngine*, QJSEngine*) -> QObject* {
         return new NameUtils;
     });
-
-    qmlRegisterSingletonType<MessageDialogHelper>(uri, 1, 0, "MessageDialogHelper", [](QQmlEngine*, QJSEngine*) -> QObject* {
-        return new MessageDialogHelper;
-    });
 }
 
 #include "componentsplugin.moc"
